[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
# GUI Clients
Git comes with built-in GUI tools for committing ([git-gui](https://git-scm.com/docs/git-gui)) and browsing ([gitk](https://git-scm.com/docs/gitk)), but there are several third-party tools for users looking for platform-specific experience.
If you want to add another GUI tool to this list, just [follow the instructions](https://github.com/git/git-scm.com/tree/gh-pages?tab=readme-ov-file#adding-a-new-gui).
[All](https://git-scm.com/tools/guis) [Windows](https://git-scm.com/tools/guis) [Mac](https://git-scm.com/tools/guis) [Linux](https://git-scm.com/tools/guis) [Android](https://git-scm.com/tools/guis) [iOS](https://git-scm.com/tools/guis)
**0** Linux GUIs are shown below ↓
  * [ ![](https://git-scm.com/images/guis/github-desktop@2x.png) ](https://desktop.github.com/)
####  [GitHub Desktop](https://desktop.github.com/)
**Platforms:** Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/sourcetree@2x.png) ](https://www.sourcetreeapp.com/)
####  [SourceTree](https://www.sourcetreeapp.com/)
**Platforms:** Mac, Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitkraken-2024@2x.png) ](https://www.gitkraken.com/git-client)
####  [GitKraken Desktop](https://www.gitkraken.com/git-client)
**Platforms:** Linux, Mac, Windows
**Price:** Free / $48+/user annually
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/tortoisegit@2x.png) ](https://tortoisegit.org/)
####  [TortoiseGit](https://tortoisegit.org/)
**Platforms:** Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/magit@2x.png) ](https://magit.vc)
####  [Magit](https://magit.vc)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/git-extensions@2x.png) ](https://gitextensions.github.io/)
####  [Git Extensions](https://gitextensions.github.io/)
**Platforms:** Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/smartgit@2x.png) ](https://www.syntevo.com/smartgit/)
####  [SmartGit](https://www.syntevo.com/smartgit/)
**Platforms:** Linux, Mac, Windows
**Price:** Free for non-commercial use / $59/user annually
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/tower@2x.png) ](https://www.git-tower.com/)
####  [Tower](https://www.git-tower.com/)
**Platforms:** Mac, Windows
**Price:** $69+/user annually (Free 30-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/megit@2x.png) ](https://github.com/eclipsesource/megit)
####  [MeGit (based on EGit)](https://github.com/eclipsesource/megit)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** EPL2.0
  * [ ![](https://git-scm.com/images/guis/smerge@2x.png) ](https://www.sublimemerge.com)
####  [Sublime Merge](https://www.sublimemerge.com)
**Platforms:** Linux, Mac, Windows
**Price:** $99/user / $75/user annually (Free evaluation)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitup@2x.png) ](http://gitup.co/)
####  [GitUp](http://gitup.co/)
**Platforms:** Mac
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/fork@2x.png) ](https://git-fork.com/)
####  [Fork](https://git-fork.com/)
**Platforms:** Mac, Windows
**Price:** $59.99 (Free evaluation)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/git-glint@2x.png) ](https://glint.info)
####  [Glint](https://glint.info)
**Platforms:** Linux, Mac, Windows
**Price:** Free / $35/user annually
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitg@2x.png) ](https://wiki.gnome.org/Apps/Gitg/)
####  [gitg](https://wiki.gnome.org/Apps/Gitg/)
**Platforms:** Linux, Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/ungit@2x.png) ](https://github.com/FredrikNoren/ungit)
####  [ungit](https://github.com/FredrikNoren/ungit)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/fugitive@2x.png) ](https://github.com/tpope/vim-fugitive)
####  [Fugitive](https://github.com/tpope/vim-fugitive)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** Vim
  * [ ![](https://git-scm.com/images/guis/gitahead@2x.png) ](https://gitahead.github.io/gitahead.com/)
####  [GitAhead (no longer under active development)](https://gitahead.github.io/gitahead.com/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/lazygit@2x.png) ](https://github.com/jesseduffield/lazygit)
####  [LazyGit](https://github.com/jesseduffield/lazygit)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/tig@2x.png) ](https://github.com/jonas/tig#readme)
####  [tig](https://github.com/jonas/tig#readme)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** GPL-2.0
  * [ ![](https://git-scm.com/images/guis/guitar@2x.png) ](https://github.com/soramimi/Guitar)
####  [Guitar](https://github.com/soramimi/Guitar)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/gitbutler.png) ](https://gitbutler.com)
####  [GitButler](https://gitbutler.com)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** FSL-1.1-MIT
  * [ ![](https://git-scm.com/images/guis/anchorpoint@2x.png) ](https://anchorpoint.app)
####  [Anchorpoint](https://anchorpoint.app)
**Platforms:** Mac, Windows
**Price:** Free / 20€
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/workingcopy@2x.png) ](https://workingcopyapp.com/)
####  [Working Copy](https://workingcopyapp.com/)
**Platforms:** iOS
**Price:** Free / $19.99
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitfox@2x.png) ](https://www.gitfox.app)
####  [Gitfox](https://www.gitfox.app)
**Platforms:** Mac
**Price:** €39,99/user annually / €79,99 (Free 30-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/git-cola@2x.png) ](https://git-cola.github.io/)
####  [git-cola](https://git-cola.github.io/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/gitui@2x.png) ](http://gitui.org)
####  [GitUI](http://gitui.org)
**Platforms:** Linux, Mac, Windows
**Price:** Free, but donations welcome
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/giggle@2x.png) ](https://wiki.gnome.org/Apps/giggle/)
####  [giggle (no longer under active development)](https://wiki.gnome.org/Apps/giggle/)
**Platforms:** Linux
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/aurees@2x.png) ](https://aurees.com/)
####  [Aurees (no longer under active development)](https://aurees.com/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/meldmerge.png) ](https://meldmerge.org)
####  [Meld](https://meldmerge.org)
**Platforms:** Linux, Windows
**Price:** Free
**License:** GPLv2 or later
  * [ ![](https://git-scm.com/images/guis/snailgit@2x.png) ](https://langui.net/snailgit/)
####  [SnailGit](https://langui.net/snailgit/)
**Platforms:** Mac
**Price:** Free (limited) / $9.99
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/repoz@2x.png) ](https://github.com/awaescher/RepoZ/)
####  [RepoZ](https://github.com/awaescher/RepoZ/)
**Platforms:** Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/cong@2x.png) ](http://cong.tools/)
####  [Cong](http://cong.tools/)
**Platforms:** Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitdrive@2x.png) ](http://gitdrive.com/)
####  [GitDrive](http://gitdrive.com/)
**Platforms:** iOS
**Price:** Free / $6.99
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitfiend@2x.png) ](https://gitfiend.com)
####  [GitFiend](https://gitfiend.com)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitatomic@2x.png) ](https://gitatomic.bitbucket.io/)
####  [GitAtomic](https://gitatomic.bitbucket.io/)
**Platforms:** Windows
**Price:** $17.99+/user annually (Free 30-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/nitrogit@2x.png) ](http://nitrogit.net)
####  [NitroGit](http://nitrogit.net)
**Platforms:** Windows
**Price:** Free for non-commercial use / 20€/user
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitfinder@2x.png) ](https://gitfinder.com)
####  [GitFinder](https://gitfinder.com)
**Platforms:** Mac
**Price:** Free (limited) / $29.95 (Free 30-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/vershd@2x.png) ](https://vershd.io/)
####  [Vershd](https://vershd.io/)
**Platforms:** Linux, Mac, Windows
**Price:** Free for non-commercial use / $37/user annually
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitvine@2x.png) ](https://insanesharpness.gitlab.io/GitVine)
####  [GitVine](https://insanesharpness.gitlab.io/GitVine)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/polygit@2x.png) ](http://www.polygitapp.com)
####  [PolyGit](http://www.polygitapp.com)
**Platforms:** iOS
**Price:** Free (limited) / $11.99/year / $39.99
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitgui@2x.png) ](https://github.com/jjustra/gitgui)
####  [Gitgui](https://github.com/jjustra/gitgui)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/gittyup@2x.png) ](https://murmele.github.io/Gittyup/)
####  [Gittyup](https://murmele.github.io/Gittyup/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/gitklient@2x.png) ](https://invent.kde.org/sdk/kommit)
####  [Kommit](https://invent.kde.org/sdk/kommit)
**Platforms:** Linux
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/gitviewer@2x.png) ](https://gitviewer.com)
####  [GitViewer](https://gitviewer.com)
**Platforms:** iOS, Mac
**Price:** Free / $6.99 (Free 7-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/CommandGit@2x.png) ](https://CommandGit.com)
####  [CommandGit](https://CommandGit.com)
**Platforms:** Windows
**Price:** $5.99/MO (Free 14-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/gitonic@2x.png) ](https://github.com/kr-g/gitonic)
####  [gitonic](https://github.com/kr-g/gitonic)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** AGPL-3.0-or-later
  * [ ![](https://git-scm.com/images/guis/Gitnuro@2x.png) ](https://gitnuro.com/)
####  [Gitnuro](https://gitnuro.com/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** GNU GPL
  * [ ![](https://git-scm.com/images/guis/gitbreeze@2x.png) ](https://gitbreeze.dev/)
####  [GitBreeze](https://gitbreeze.dev/)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/pragmagit@2x.png) ](https://pragma-git.github.io)
####  [Pragma-git](https://pragma-git.github.io)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/gk-cli-keifs@2x.png) ](https://www.gitkraken.com/cli)
####  [GitKraken CLI](https://www.gitkraken.com/cli)
**Platforms:** Linux, Mac, Windows
**Price:** Free / $48.00+/user annually
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/sourcegit@2x.png) ](https://sourcegit-scm.github.io)
####  [SourceGit](https://sourcegit-scm.github.io)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** MIT
  * [ ![](https://git-scm.com/images/guis/relagit@2x.png) ](https://rela.dev)
####  [RelaGit](https://rela.dev)
**Platforms:** Linux, Mac, Windows
**Price:** Free
**License:** LGPL-3.0-or-later
  * [ ![](https://git-scm.com/images/guis/puppygit@2x.png) ](https://github.com/catpuppyapp/PuppyGit)
####  [Puppy Git](https://github.com/catpuppyapp/PuppyGit)
**Platforms:** Android
**Price:** Free
**License:** GPLv3
  * [ ![](https://git-scm.com/images/guis/retcon@2x.png) ](https://retcon.app)
####  [Retcon](https://retcon.app)
**Platforms:** Mac
**Price:** $49.99/user annually (Free 14-day trial)
**License:** Proprietary
  * [ ![](https://git-scm.com/images/guis/changes@2x.png) ](https://github.com/maoyama/Changes)
####  [Changes](https://github.com/maoyama/Changes)
**Platforms:** Mac
**Price:** Free
**License:** MIT


There are other great GUI tools available as well. Have a look at the list of [interfaces, frontends and tools](https://git.wiki.kernel.org/index.php/InterfacesFrontendsAndTools) in the Git Wiki.
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
